django-radagast
===========================

Radagast: the wizard no-one has heard of.

A wizard that is similar to the one in Django except that:

* It uses jinja2 and jingo.
* It will work with or without Ajax.
* The path it takes can change.
* You don't need to have a form on every page.
* It does a lot less.
* It lets you work with views in the normal way, if that's what you want.
* You can set URL paths to specific parts of the wizard.

License: BSD

Author: Andy McKay, amckay@mozilla.com
